<!--- README template from https://github.com/scottydocs/README-template.md -->
<!-- No pypi or build yet
[![license](https://img.shields.io/pypi/l/OneMod)](https://github.com/ihmeuw-msca/OneMod/blob/main/LICENSE)
[![version](https://img.shields.io/pypi/v/OneMod)](https://pypi.org/project/OneMod)
[![build](https://img.shields.io/github/actions/workflow/status/ihmeuw-msca/OneMod/build.yml?branch=main)](https://github.com/ihmeuw-msca/OneMod/actions)
-->
[![docs](https://img.shields.io/badge/docs-here-green)](https://ihmeuw-msca.github.io/OneMod)
[![codecov](https://img.shields.io/codecov/c/github/ihmeuw-msca/OneMod)](https://codecov.io/gh/ihmeuw-msca/OneMod)
[![codacy](https://img.shields.io/codacy/grade/ae72a07785f5469eac234d1f6bdf555f)](https://app.codacy.com/gh/ihmeuw-msca/OneMod/dashboard?utm_source=gh&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)

# OneMod

**OneMod** is an orchestration package that allows users to build pipelines of
various models created by [IHME Math Sciences](https://github.com/ihmeuw-msca).
Core features of **OneMod** include an intuitive syntax for defining the
dataflow between pipeline stages, the ability to easily parallelize over
different data subsets and/or parameter sets, and options for data validation.
Advanced users can also define their own custom stages.

For instructions on how to install and use OneMod, please refer to the
[documentation](https://ihmeuw-msca.github.io/OneMod/).

## License

This project uses the following license: [BSD 2-Clause](./LICENSE)
